@@ -8,7 +8,7 @@ import types
 from textwrap import dedent
 
 from ..parameters import (
-    backendRep,
+    BACKEND_REP,
     URL_TFDOC,
     SEARCHREF,
     APIREF,
@@ -73,7 +73,7 @@ def linksApi(app, silent=SILENT_D):
     charText = aContext.charText
 
     tutUrl = (
-        f"{backendRep(backend, 'urlnb')}/"
+        f"{BACKEND_REP(backend, 'urlnb')}/"
         f"{org}/{repo}/blob/master/tutorial/start.ipynb"
     )
     apiVersionRep = "" if apiVersion is None else f" v{apiVersion}"
@@ -124,7 +124,7 @@ def linksApi(app, silent=SILENT_D):
         if isCompatible
         else UNSUPPORTED
     )
-    extraUrl = f"{backendRep(backend, 'url')}/{org}/{repo}/blob/master/{APP_APP}"
+    extraUrl = f"{BACKEND_REP(backend, 'url')}/{org}/{repo}/blob/master/{APP_APP}"
     appLink = (
         outLink(
             f"{org}/{repo}/app {apiVersionRep}",
@@ -153,9 +153,9 @@ def linksApi(app, silent=SILENT_D):
     )
     tutLink = (
         outLink(
-            "App tutorial",
+            "Tutorial",
             tutUrl,
-            "App tutorial in Jupyter Notebook",
+            "Tutorial in Jupyter Notebook",
             asHtml=inNb or _browse,
         )
         if isCompatible and repo is not None
@@ -201,38 +201,58 @@ def header(app, allMeta=False):
     tutLink = app.tutLink
 
     if app._browse:
-        return (
-            f"""\
-<div class="hdlinks">
-  {dataLink}
-  {charLink}
-  {featureLink}
-  {tfsLink}
-  {tutLink}
-</div>\
-""",
-            '<img class="hdlogo" src="/data/static/logo.png"/>',
-            '<img class="hdlogo" src="/server/static/icon.png"/>',
+        colofon = dedent(
+            f"""
+            <div class="hdlinks">
+              {dataLink}
+              {charLink}
+              {featureLink}
+              {tfsLink}
+              {tutLink}
+            </div>
+            """
         )
     else:
-        featureInfo = _featuresPerModule(app, allMeta=allMeta)
+        colofon = ""
+
+    nodeInfo = _nodeTypeInfo(app)
+    featureInfo = _featuresPerModule(app, allMeta=allMeta or app._browse)
+    if inNb or app._browse:
+        tfLine = ", ".join(x for x in (tfLink, appLink, tfsLink) if x)
+        dataLine = ", ".join(x for x in (dataLink, charLink, featureLink) if x)
+        setLine = (
+            ", ".join(f"<code>{x}</code>" for x in (app.sets or {}))
+            if app.sets
+            else "no custom sets"
+        )
+        commonHeader = dedent(
+            f"""
+            <b>Text-Fabric:</b> {tfLine}<br>
+            <b>Data:</b> {dataLine}<br>
+            {nodeInfo}
+            <b>Sets:</b> {setLine}<br>
+            <b>Features:</b><br>{featureInfo}
+            """
+        )
         if inNb:
-            tfLine = ", ".join(x for x in (tfLink, appLink, tfsLink) if x)
-            dataLine = ", ".join(x for x in (dataLink, charLink, featureLink) if x)
-            dh(
-                f"<b>Text-Fabric:</b> {tfLine}<br>"
-                f"<b>Data:</b> {dataLine}<br>"
-                f"<b>Features:</b><br>{featureInfo}"
-            )
+            dh(commonHeader)
         else:
-            tfLine = "\n\t".join(x for x in (tfLink, appLink, tfsLink) if x)
-            dataLine = "\n\t".join(x for x in (dataLink, charLink, featureLink) if x)
-            console(
-                f"Text-Fabric:\n\t{tfLine}\n"
-                f"Data:\n\t{dataLine}\n"
-                f"Features:\n{featureInfo}\n",
-                newline=False,
+            return (
+                colofon,
+                commonHeader,
+                '<img class="hdlogo" src="/data/static/logo.png"/>',
+                '<img class="hdlogo" src="/server/static/icon.png"/>',
             )
+    else:
+        tfLine = "\n\t".join(x for x in (tfLink, appLink, tfsLink) if x)
+        dataLine = "\n\t".join(x for x in (dataLink, charLink, featureLink) if x)
+        setLine = ", ".join(x for x in (app.sets or {}))
+        console(
+            f"Text-Fabric:\n\t{tfLine}\n" f"Data:\n\t{dataLine}\n" f"{nodeInfo}",
+            f"Sets: {setLine}\n",
+            f"Features:\n{featureInfo}\n",
+            newline=False,
+        )
 
 
 def webLink(
@@ -515,6 +535,72 @@ def outLink(
     )
 
 
+def _nodeTypeInfo(app):
+    inNb = app.inNb
+    _browse = app._browse
+    doHtml = inNb or _browse
+    api = app.api
+    levels = api.C.levels.data
+    otype = api.F.otype
+    slotType = otype.slotType
+    maxSlot = otype.maxSlot
+
+    output = (
+        """<details class="nodeinfo"><summary><b>Node types</b></summary>"""
+        if doHtml
+        else "Node types:\n"
+    )
+
+    if doHtml:
+        output += (
+            dedent(
+                """
+            <table class="nodeinfo">
+                <tr>
+                    <th>Name</th>
+                    <th># of nodes</th>
+                    <th># slots/node</th>
+                    <th>% coverage</th>
+                <tr>
+            """
+            )
+            if doHtml
+            else f"{'Name':<20} {'#nodes':>7} {'#slots/node':>11} {'%coverage':>9}\n"
+        )
+    for (nType, av, start, end) in levels:
+        nNodes = end - start + 1
+        coverage = int(round(av * nNodes * 100 / maxSlot))
+        coverage = (
+            (f"<b>{coverage}</b>" if doHtml else f"= {coverage:>7}")
+            if coverage == 100
+            else (f"<i>{coverage}</i>" if doHtml else f"> {coverage:>7}")
+            if coverage > 100
+            else coverage
+        )
+        nTypeRep = (
+            (f"<i>{nType}</i>" if doHtml else f"*{nType}*")
+            if nType == slotType
+            else nType
+        )
+        output += (
+            dedent(
+                f"""
+            <tr>
+                <th>{nTypeRep}</th>
+                <td>{nNodes}</td>
+                <td>{av:.2f}</td>
+                <td>{coverage}</td>
+            </tr>
+            """
+            )
+            if doHtml
+            else f"{nTypeRep:<20} {nNodes:>7} {av:8.2f} {coverage:>9}\n"
+        )
+
+    output += "</table></details>" if doHtml else "\n"
+    return output
+
+
 def _featuresPerModule(app, allMeta=False):
     """Generate a formatted list of loaded TF features, per module.
 
@@ -531,6 +617,8 @@ def _featuresPerModule(app, allMeta=False):
     api = app.api
     TF = app.TF
     inNb = app.inNb
+    _browse = app._browse
+    doHtml = inNb or _browse
     backend = app.backend
 
     aContext = app.context
@@ -575,8 +663,8 @@ def _featuresPerModule(app, allMeta=False):
                 else fixedModuleIndex[mId]
                 if mId in fixedModuleIndex
                 else (
-                    f"{backendRep(backend, 'rep')}{org}/{repo}/{relative}",
-                    f"{backendRep(backend, 'url')}/{org}/{repo}/tree/master/{relative}",
+                    f"{BACKEND_REP(backend, 'rep')}{org}/{repo}/{relative}",
+                    f"{BACKEND_REP(backend, 'url')}/{org}/{repo}/tree/master/{relative}",
                 )
             )
             moduleIndex[mId] = (theBackend, org, repo, relative, corpus, docUrl)
@@ -643,7 +731,7 @@ def _featuresPerModule(app, allMeta=False):
                 ""
                 if type(mId) is str
                 else (
-                    f"{backendRep(mBackend, 'url')}/"
+                    f"{BACKEND_REP(mBackend, 'url')}/"
                     f"{mId[0]}/{mId[1]}/tree/master/{mId[2]}"
                 )
             )
@@ -654,7 +742,7 @@ def _featuresPerModule(app, allMeta=False):
                 <div class="fcorpus">
         """
             )
-            if inNb
+            if doHtml
             else f"{corpus}\n"
         )
 
@@ -679,7 +767,7 @@ def _featuresPerModule(app, allMeta=False):
             description = meta.get("description", "")
 
             edgeRep = "edge" if isEdge else ""
-            if inNb:
+            if doHtml:
                 output += dedent(
                     f"""
                         <div class="frow">
@@ -697,17 +785,17 @@ def _featuresPerModule(app, allMeta=False):
                     if docUrl
                     else f'<span title="{featurePath}">{featureRep}</span>'
                 )
-                if inNb
+                if doHtml
                 else f"\t{featureRep:<20} "
             )
-            if inNb:
+            if doHtml:
                 output += dedent(
                     f"""
                             </div>
                             <div class="fmono">{typeRep}</div>
                     """
                 )
-            if inNb:
+            if doHtml:
                 output += dedent(
                     f"""
                             <details>
@@ -724,7 +812,7 @@ def _featuresPerModule(app, allMeta=False):
             if allMeta:
                 for (k, v) in sorted(meta.items()):
                     if k not in {"valueType", "description"}:
-                        if inNb:
+                        if doHtml:
                             k = htmlEsc(k)
                             v = htmlEsc(v)
                             output += dedent(
@@ -737,7 +825,7 @@ def _featuresPerModule(app, allMeta=False):
                             )
                         else:
                             output += f"\t\t{k}: {v}\n"
-                if inNb:
+                if doHtml:
                     output += dedent(
                         """
                                     </div>
@@ -746,13 +834,13 @@ def _featuresPerModule(app, allMeta=False):
                     )
                 else:
                     output += "\n"
-            if inNb:
+            if doHtml:
                 output += dedent(
                     """
                         </div>
                     """
                 )
-        if inNb:
+        if doHtml:
             output += dedent(
                 """
                     </div>
@@ -799,7 +887,7 @@ def provenanceLink(backend, org, repo, version, commit, local, release, relative
         )
     )
     relativeFlat = relative.replace("/", "-")
-    bUrl = backendRep(backend, "url")
+    bUrl = BACKEND_REP(backend, "url")
     url = (
         None
         if org is None or repo is None
