@@ -389,27 +389,31 @@ import os
 import io
 import re
 from shutil import rmtree
-import requests
 import base64
 from zipfile import ZipFile
 
-from github import Github, GithubException, UnknownObjectException
-from gitlab import Gitlab
-from gitlab.exceptions import GitlabGetError
-
 from ..parameters import (
     GH,
     URL_TFDOC,
-    backendRep,
+    BACKEND_REP,
     EXPRESS_SYNC,
     EXPRESS_SYNC_LEGACY,
     DOWNLOADS,
 )
-from ..core.helpers import console, htmlEsc, expanduser, initTree
+from ..core.helpers import console, htmlEsc, expanduser, initTree, unexpanduser
 from ..core.timestamp import SILENT_D, AUTO, TERSE, VERBOSE, silentConvert
+from ..capable import Capable
 from .helpers import dh, runsInNotebook
 from .zipdata import zipData
 
+Cap = Capable("github", "gitlab")
+requests = Cap.load("requests")
+(Github, GithubException, UnknownObjectException) = Cap.loadFrom(
+    "github", "Github", "GithubException", "UnknownObjectException"
+)
+(Gitlab, GitlabGetError) = Cap.loadFrom("gitlab", "Gitlab", "GitlabGetError")
+requestsExceptions = Cap.loadFrom("requests", "exceptions")
+ConnectionError = requestsExceptions.ConnectionError
 
 VERSION_DIGIT_RE = re.compile(r"^([0-9]+).*")
 SHELL_VAR_RE = re.compile(r"[^A-Z0-9_]")
@@ -419,6 +423,16 @@ def GLPERS(backend):
     return f"GL_{SHELL_VAR_RE.sub('_', backend.upper())}_PERS"
 
 
+def catchRemaining(e):
+    eType = type(e)
+    if eType is ConnectionError:
+        console("no internet connection", error=True)
+    elif eType is IOError:
+        console("no internet", error=True)
+    else:
+        console(f"unexpected error from {e.__class__.__module__}: {str(e)}")
+
+
 class Repo:
     """Auxiliary class for `releaseData`"""
 
@@ -430,7 +444,7 @@ class Repo:
         folder,
         version,
         increase,
-        source=backendRep(GH, "clone"),
+        source=BACKEND_REP(GH, "clone"),
         dest=DOWNLOADS,
     ):
         self.org = org
@@ -502,6 +516,19 @@ class Repo:
         backend = self.backend
         conn = self.conn
 
+        if backend != "github":
+            console(
+                "Release preparation not implemented for {backend}, only for github",
+                error=True,
+            )
+            return None
+
+        backendTech = BACKEND_REP(backend, "tech")
+
+        if not Cap.can(backendTech):
+            self.conn = None
+            return
+
         if not conn:
             ghPerson = os.environ.get("GHPERS", None)
             if ghPerson:
@@ -531,11 +558,12 @@ class Repo:
             )
             self.repoOnline = conn.get_repo(f"{self.org}/{self.repo}")
             self.info("connected")
-        except GithubException as why:
+        except Exception as e:
             self.warning("failed")
-            self.warning(f"{backend} says: {why}")
-        except IOError:
-            self.warning("no internet")
+            if type(e) is GithubException:
+                self.warning(f"{backend} says: {str(e)}")
+            else:
+                catchRemaining(e)
 
         self.conn = conn
         return conn
@@ -606,8 +634,7 @@ class Repo:
             )
         except Exception as e:
             self.error("\tcannot create release", newline=True)
-            console(str(e), error=True)
-            return False
+            catchRemaining(e)
 
         self.newReleaseObj = newReleaseObj
         return True
@@ -635,7 +662,7 @@ class Repo:
             console(f"{dataFile} attached to release {newTag}")
         except Exception as e:
             self.error("\tcannot attach zipfile to release", newline=True)
-            console(str(e), error=True)
+            catchRemaining(e)
             return False
 
         return True
@@ -655,10 +682,12 @@ class Repo:
 
         try:
             r = g.get_latest_release()
-        except UnknownObjectException:
+        except Exception as e:
             self.error("\tno releases", newline=True)
-        except Exception:
-            self.error("\tcannot find releases", newline=True)
+            if type(e) is UnknownObjectException:
+                self.error("\tcannot find releases", newline=True)
+            else:
+                catchRemaining(e)
         return r
 
     def getCommit(self):
@@ -680,8 +709,9 @@ class Repo:
                 c = cs[0]
             else:
                 self.error("\tno commits")
-        except Exception:
+        except Exception as e:
             self.error("\tcannot find commits")
+            catchRemaining(e)
         return c
 
     def info(self, msg, newline=True):
@@ -741,8 +771,9 @@ def releaseData(
     dest: string, optional `DOWNLOADS`
         Path to where the zipped data should be stored
     """
+
     if source is None or not source:
-        source = (backendRep(GH, "clone"),)
+        source = (BACKEND_REP(GH, "clone"),)
 
     R = Repo(GH, org, repo, folder, version, increase, source=source, dest=dest)
     return R.newRelease()
@@ -782,9 +813,9 @@ class Checkout:
         extra = ""
         if local:
             if source is None:
-                source = backendRep(backend, "clone")
+                source = BACKEND_REP(backend, "clone")
             if dest is None:
-                dest = backendRep(backend, "cache")
+                dest = BACKEND_REP(backend, "cache")
 
             baseRep = source if local == "clone" else dest
             extra = f" offline under {baseRep}"
@@ -898,12 +929,24 @@ class Checkout:
         conn = self.conn
         backend = self.backend
 
+        backendTech = BACKEND_REP(backend, "tech")
+
+        if not Cap.can(backendTech):
+            self.conn = None
+            return None
+
         self.canDownloadSubfolders = False
 
         if onGithub:
             person = os.environ.get("GHPERS", None)
             if person:
-                conn = Github(person)
+                try:
+                    conn = Github(person)
+                except Exception as e:
+                    self.error(f"Can't make connection to Github because of {e}")
+                    self.conn = None
+                    catchRemaining(e)
+                    return None
             else:
                 client = os.environ.get("GHCLIENT", None)
                 secret = os.environ.get("GHSECRET", None)
@@ -912,8 +955,8 @@ class Checkout:
                 else:
                     conn = Github()
         else:
-            bUrl = backendRep(backend, "url")
-            bMachine = backendRep(backend, "machine")
+            bUrl = BACKEND_REP(backend, "url")
+            bMachine = BACKEND_REP(backend, "machine")
 
             person = os.environ.get(GLPERS(bMachine), None)
             if person:
@@ -959,7 +1002,7 @@ class Checkout:
         org = self.org
         repo = self.repo
 
-        bName = backendRep(backend, "name")
+        bName = BACKEND_REP(backend, "name")
 
         if not conn:
             conn = self.login()
@@ -979,9 +1022,12 @@ class Checkout:
                         f"see {URL_TFDOC}/advanced/repo.html#github"
                     )
 
-            except GithubException as why:
+            except Exception as e:
                 self.warning("Could not get rate limit details")
-                self.warning(f"{bName} says: {why}")
+                if type(e) is GithubException:
+                    self.warning(f"{bName} says: {e}")
+                else:
+                    catchRemaining(e)
 
         self.info(
             f"\tconnecting to online {bName} repo {org}/{repo} ... ",
@@ -989,25 +1035,26 @@ class Checkout:
         )
         repoOnline = None
 
-        try:
-            if onGithub:
-                try:
-                    repoOnline = conn.get_repo(f"{org}/{repo}")
-                    self.info("connected")
-                except GithubException as why:
-                    self.warning("failed")
-                    self.warning(f"{bName} says: {why}")
-            else:
-                try:
-                    repoOnline = conn.projects.get(f"{org}/{repo}")
-                    self.info("connected")
-                except GitlabGetError as why:
-                    self.warning("failed")
-                    self.warning(f"{bName} says: {why}")
-        except IOError as why:
-            self.warning("no internet")
-            self.warning("failed")
-            self.warning(f"{bName} says: {why}")
+        if onGithub:
+            try:
+                repoOnline = conn.get_repo(f"{org}/{repo}")
+                self.info("connected")
+            except Exception as e:
+                self.warning("failed")
+                if type(e) is GithubException:
+                    self.warning(f"{bName} says: {e}")
+                else:
+                    catchRemaining(e)
+        else:
+            try:
+                repoOnline = conn.projects.get(f"{org}/{repo}")
+                self.info("connected")
+            except Exception as e:
+                self.warning("failed")
+                if type(e) is GitlabGetError:
+                    self.warning(f"{bName} says: {e}")
+                else:
+                    catchRemaining(e)
 
         self.repoOnline = repoOnline
 
@@ -1146,6 +1193,7 @@ class Checkout:
                         self.error("No online connection")
                 elif not isOnline:
                     self.error(f"The requested {label} is not available online")
+                    self.error("C")
                 else:
                     self.localBase = self.baseLocal if self.download() else False
 
@@ -1182,7 +1230,8 @@ class Checkout:
             stateEsc = htmlEsc(state)
             offEsc = htmlEsc(offString)
             loc = f"{self.localBase}/{self.localDir}{self.versionRep}"
-            locEsc = htmlEsc(loc)
+            locRep = unexpanduser(loc)
+            locEsc = htmlEsc(locRep)
             if _browse:
                 self.info(
                     f"Using {label} in {self.localBase}/{self.localDir}{self.versionRep}:"
@@ -1194,7 +1243,7 @@ class Checkout:
                         f'<b title="{stateEsc}">{labelEsc}:</b>'
                         f' <span title="{offEsc}">{locEsc}</span>'
                     ),
-                    f"{label}: {loc}",
+                    f"{label}: {locRep}",
                 )
 
     def download(self):
@@ -1287,7 +1336,7 @@ class Checkout:
             again = True
         else:
             g = where
-            notice = backendRep(backend, "name")
+            notice = BACKEND_REP(backend, "name")
             again = False
 
         self.info(f"\tdownloading from {notice} ... ")
@@ -1312,7 +1361,7 @@ class Checkout:
                             again=False,
                         )
                         msg = "\tFailed"
-                        self.possibleError(msg, showErrors=showErrors)
+                        self.possibleError(msg, showErrors=showErrors, newline=True)
                         return False
                 else:
                     zf = g.repository_archive(format="zip", sha=commit)
@@ -1388,10 +1437,11 @@ class Checkout:
                         again=False,
                     )
                     msg = "\tFailed"
-                    self.possibleError(msg, showErrors=showErrors)
+                    self.possibleError(msg, showErrors=showErrors, newline=True)
                     good = False
-        except Exception:
+        except Exception as e:
             msg = f"\tcould not save {label} to {destZip}"
+            console(str(e), error=True)
             self.possibleError(msg, showErrors=showErrors, again=True)
             os.chdir(cwd)
             return False
@@ -1420,17 +1470,23 @@ class Checkout:
                 nonlocal good
                 if not good:
                     return
+
                 lead = "\t" * level
                 try:
                     contents = g.get_contents(subPath, ref=commit)
-                except UnknownObjectException:
-                    msg = (
-                        f"{lead}No directory {subPath} in "
-                        f"{self.toString(commit, None, False, backend)}"
-                    )
-                    self.possibleError(msg, showErrors, again=True, indent=lead)
+                except Exception as e:
+                    if UnknownObjectException:
+                        msg = (
+                            f"{lead}No directory {subPath} in "
+                            f"{self.toString(commit, None, False, backend)}"
+                        )
+                        self.possibleError(msg, showErrors, again=True, indent=lead)
+                    else:
+                        catchRemaining(e)
+
                     good = False
                     return
+
                 for content in contents:
                     thisPath = content.path
                     self.info(f"\t{lead}{thisPath}...", newline=False)
@@ -1449,9 +1505,14 @@ class Checkout:
                             with open(fileDest, "wb") as fd:
                                 fd.write(fileData)
                             self.info("downloaded")
-                        except (GithubException, IOError):
-                            msg = "error"
-                            self.possibleError(msg, showErrors, again=True, indent=lead)
+                        except Exception as e:
+                            if type(e) is GithubException:
+                                msg = "error"
+                                self.possibleError(
+                                    msg, showErrors, again=True, indent=lead
+                                )
+                            else:
+                                catchRemaining(e)
                             good = False
 
             _downloadDir(self.dataDir, 0)
@@ -1464,7 +1525,9 @@ class Checkout:
         else:
             if onGithub:
                 msg = "\tFailed"
-                self.possibleError(msg, showErrors=showErrors if onGithub else True)
+                self.possibleError(
+                    msg, showErrors=showErrors if onGithub else True, newline=True
+                )
 
         return good
 
@@ -1493,16 +1556,12 @@ class Checkout:
         if onGithub:
             try:
                 r = g.get_release(release) if release else g.get_latest_release()
-            except UnknownObjectException:
+            except Exception as e:
                 self.possibleError(
                     f"\tcannot find release{msg}", showErrors, newline=True
                 )
-            except Exception:
-                self.possibleError(
-                    f"\tcannot find release{msg}",
-                    showErrors,
-                    newline=True,
-                )
+                if type(e) is not UnknownObjectException:
+                    catchRemaining(e)
         else:
             try:
                 if release:
@@ -1514,8 +1573,9 @@ class Checkout:
                         if releases
                         else None
                     )
-            except Exception:
+            except Exception as e:
                 r = None
+                console(str(e), error=True)
             if r is None:
                 self.possibleError(
                     f"\tcannot find release{msg}", showErrors, newline=True
@@ -1539,8 +1599,9 @@ class Checkout:
                     c = cs[0]
                 else:
                     self.error(f"\tcannot find commit{msg}")
-            except Exception:
+            except Exception as e:
                 self.error(f"\tcannot find commit{msg}")
+                console(str(e), error=True)
         else:
             try:
                 cs = g.commits.list(all=True)
@@ -1558,8 +1619,9 @@ class Checkout:
                             c = cs[-1]
                     if c is None:
                         self.error(f"\tcannot find commit{msg}")
-            except Exception:
+            except Exception as e:
                 self.error(f"\tcannot find commit{msg}")
+                console(str(e), error=True)
         return c
 
     def getReleaseFromObj(self, r):
@@ -1763,10 +1825,10 @@ def checkoutRepo(
     silent = silentConvert(silent)
 
     if source is None:
-        source = backendRep(backend, "clone")
+        source = BACKEND_REP(backend, "clone")
 
     if dest is None:
-        dest = backendRep(backend, "cache")
+        dest = BACKEND_REP(backend, "cache")
 
     def resolve(chkout, attempt=False):
         rData = Checkout(
