@@ -16,6 +16,7 @@ from .helpers import (
     rangesFromSet,
     check32,
     console,
+    unexpanduser,
 )
 from .timestamp import SILENT_D, silentConvert
 
@@ -31,7 +32,7 @@ MEM_MSG = (
 )
 
 
-class Data(object):
+class Data:
     def __init__(
         self,
         path,
@@ -92,6 +93,7 @@ class Data(object):
             if self.method
             else self.dirName
         )
+        sourceRep = unexpanduser(sourceRep)
         msgFormat = "{:<1} {:<20} from {}"
         actionRep = ""
         good = True
@@ -117,6 +119,8 @@ class Data(object):
                 if not origTime:
                     actionRep = "b"
                     good = self._readDataBin(_withGc=_withGc)
+                    if not good:
+                        actionRep = "X"  # no source and no readable binary present
                 elif not binTime or origTime > binTime:
                     actionRep = "C" if self.method else "T"
                     good = (
@@ -137,6 +141,16 @@ class Data(object):
                             actionRep = "M"
                         else:
                             good = self._readDataBin(_withGc=_withGc)
+                            if not good:
+                                actionRep = "C" if self.method else "T"
+                                print(f"{self.method=}")
+                                good = (
+                                    self._compute(metaOnly=metaOnly)
+                                    if self.method
+                                    else self._readTf(metaOnly=metaOnly)
+                                )
+                                if good:
+                                    self._writeDataBin()
             except MemoryError:
                 console(MEM_MSG)
                 good = False
@@ -634,12 +648,20 @@ class Data(object):
             return False
         if not _withGc:
             gc.disable()
-        with gzip.open(self.binPath, "rb") as f:
-            self.data = pickle.load(f)
-        if not _withGc:
-            gc.enable()
+
+        good = True
+
+        try:
+            with gzip.open(self.binPath, "rb") as f:
+                self.data = pickle.load(f)
+            good = True
+        except Exception:
+            good = False
+        finally:
+            if not _withGc:
+                gc.enable()
         self.dataLoaded = time.time()
-        return True
+        return good
 
     def cleanDataBin(self):
         if os.path.exists(self.binPath):
