@@ -3,11 +3,7 @@ import sys
 import re
 from shutil import rmtree
 
-from ..parameters import OMAP
-
-
-def normpath(path):
-    return None if path is None else path.replace("\\", "/")
+from ..parameters import normpath, OMAP, HOME_DIR
 
 
 def abspath(path):
@@ -15,14 +11,19 @@ def abspath(path):
 
 
 def expanduser(path):
-    return normpath(os.path.expanduser(path))
+    nPath = normpath(path)
+    if nPath.startswith("~"):
+        return f"{HOME_DIR}{nPath[1:]}"
 
-
-HOME_DIR = expanduser("~")
+    return nPath
 
 
 def unexpanduser(path):
-    return normpath(path).replace(HOME_DIR, "~")
+    nPath = normpath(path)
+    if nPath.startswith(HOME_DIR):
+        return f"~{nPath[len(HOME_DIR):]}"
+
+    return nPath
 
 
 def setDir(obj):
@@ -440,18 +441,23 @@ def wrapMessages(messages):
     if type(messages) is str:
         messages = messages.split("\n")
     html = []
+    status = True
     for msg in messages:
         if type(msg) is tuple:
             (error, nl, msgRep) = msg
+            if error:
+                status = False
             match = MSG_LINE_RE.match(msgRep)
             msg = msgRep + ("<br/>" if nl else "")
             clsName = "eline" if error and not match else "tline"
         else:
             match = MSG_LINE_RE.match(msg)
             clsName = "tline" if match else "eline"
+            if clsName == "eline":
+                status = False
             msg = msg.replace("\n", "<br/>")
         html.append(f'<span class="{clsName.lower()}">{msg}</span>')
-    return "".join(html)
+    return (status, "".join(html))
 
 
 def makeExamples(nodeList):
