@@ -27,7 +27,7 @@ DEEP = "deep"
 """No output, except error messages.
 """
 
-SILENT_D = TERSE
+SILENT_D = AUTO
 """Default value for the silent parameter.
 
 The value is `"terse"`
@@ -46,7 +46,7 @@ def silentConvert(arg):
     return not not arg
 
 
-class Timestamp(object):
+class Timestamp:
     def __init__(self, silent=SILENT_D, level=None):
         """Create a controller for timed messages.
 
