@@ -121,7 +121,7 @@ An involved example of creating node mappings between versions (not using this c
 [versionMappings.ipynb](https://nbviewer.jupyter.org/github/ETCBC/bhsa/blob/master/programs/versionMappings.ipynb).
 
 A simpler example, using this code is
-[map.ipynb](https://nbviewer.jupyter.org/github/Dans-labs/clariah-gm/blob/master/programs/map.ipynb).
+[map.ipynb](https://nbviewer.jupyter.org/github/clariah/wp6-missieven/blob/master/programs/map.ipynb).
 
 ## Usage
 
@@ -135,8 +135,8 @@ V.makeVersionMapping()
 
 import sys
 import collections
-import time
 from itertools import chain
+from ..core.timestamp import SILENT_D, VERBOSE, AUTO, TERSE, silentConvert
 
 
 STAT_LABELS = collections.OrderedDict(
@@ -151,94 +151,30 @@ STAT_LABELS = collections.OrderedDict(
 TIMESTAMP = None
 
 
-def _duration():
-    global TIMESTAMP
-    if TIMESTAMP is None:
-        TIMESTAMP = time.time()
-
-    interval = time.time() - TIMESTAMP
-    if interval < 10:
-        return "{: 2.2f}s".format(interval)
-    interval = int(round(interval))
-    if interval < 60:
-        return "{:>2d}s".format(interval)
-    if interval < 3600:
-        return "{:>2d}m {:>02d}s".format(interval // 60, interval % 60)
-    return "{:>2d}h {:>02d}m {:>02d}s".format(
-        interval // 3600, (interval % 3600) // 60, interval % 60
-    )
-
-
-def caption(level, heading, good=None, newLine=True, continuation=False):
-    prefix = "" if good is None else "SUCCES " if good else "FAILURE "
-    duration = "" if continuation else "{:>11} ".format(_duration())
-    reportHeading = "{}{}{}".format(duration, prefix, heading)
-
-    if level == 0:  # non-heading message
-        decoration = "" if continuation else "| "
-        formattedString = """{}{}""".format(decoration, reportHeading)
-    elif level == 1:  # pipeline level
-        formattedString = """
-##{}##
-# {} #
-# {} #
-# {} #
-##{}##
-""".format(
-            "#" * 90,
-            " " * 90,
-            "{:<90}".format(reportHeading),
-            " " * 90,
-            "#" * 90,
-        )
-    elif level == 2:  # repo level
-        formattedString = """
-**{}**
-* {} *
-* {} *
-* {} *
-**{}**
-""".format(
-            "*" * 90,
-            " " * 90,
-            "{:<90}".format(reportHeading),
-            " " * 90,
-            "*" * 90,
-        )
-    elif level == 3:  # task level
-        formattedString = """
---{}--
-- {} -
---{}--
-""".format(
-            "-" * 90,
-            "{:<90}".format(reportHeading),
-            "-" * 90,
-        )
-    elif level == 4:  # caption within task execution
-        formattedString = """..{}..
-. {} .
-..{}..""".format(
-            "." * 90,
-            "{:<90}".format(reportHeading),
-            "." * 90,
-        )
-    if newLine:
-        print(formattedString)
-    else:
-        sys.stdout.write(formattedString)
-
-
 class Versions:
-    def __init__(self, api, va, vb, slotMap=None):
+    def __init__(self, api, va, vb, silent=SILENT_D, slotMap=None):
         """Map the nodes of a nodetype between two versions of a TF dataset.
 
+        There are two scenarios in which you can use this object:
+
+        **Extend a slot map to a node mapping**.
+
         If this object is initialized with a `slotMap`, it can
         extend that mapping to a complete node mapping and save the mapping
-        as an `f"omap#{va}-{vb}"` edge feature in the dataset version `vb`.
+        as an `f"omap@{va}-{vb}"` edge feature in the dataset version `vb`.
 
-        Without a slotMap, and assuming such an omap edge is present,
-        it can map node features between the versions.
+        In this use case, the apis for both `va` and `vb` should be full TF APIs,
+        in particular, they should provide the `tf.core.locality` API.
+
+        **Use an existing node map to upgrade features from one version to another**.
+
+        In this use case, you do not have to pass a `slotMap`,
+        but in the `vb` dataset there should be an `omap@a-b` feature,
+        i.e. a node map from the nodes of `va` to those of `vb`.
+
+        The apis for both `va` and `vb` may be partial TF APIs, which means that they
+        only have to provide the `tf.core.nodefeature.NodeFeatures` (`F`) and
+        `tf.core.edgefeature.EdgeFeatures` (`E`) apis.
 
         Parameters
         ----------
@@ -250,22 +186,28 @@ class Versions:
             version label of the version whose nodes are the target of the mapping
         slotMap: dict, optional `None`
             The actual mapping between slots of the old version and the new version
+        silent: string, optional `tf.core.timestamp.SILENT_D`
+            See `tf.core.timestamp.Timestamp`
         """
+        self.silent = silentConvert(silent)
         self.api = api
         self.va = va
         self.vb = vb
         self.edge = slotMap
         self.good = True
         for v in (va, vb):
-            if va not in api:
-                print(f"No TF-API for version {va} in the `api` parameter.")
+            if v not in api:
+                sys.stderr.write(
+                    f"No TF-API for version {va} in the `api` parameter.\n"
+                )
                 self.good = False
 
         if not self.good:
             return
 
-        self.La = api[va].L
-        self.Lb = api[vb].L
+        # self.La = api[va].L
+        if slotMap is not None:
+            self.Lb = api[vb].L
         self.Ea = api[va].E
         self.Esa = api[va].Es
         self.Eb = api[vb].E
@@ -276,10 +218,19 @@ class Versions:
         self.Fsb = api[vb].Fs
         self.TFa = api[va].TF
         self.TFb = api[vb].TF
+        self.info = self.TFb.info
+        self.warning = self.TFb.warning
+        self.error = self.TFb.error
 
         self.diagnosis = {}
 
     def makeNodeMapping(self, nodeType):
+        edge = self.edge
+
+        if edge is None:
+            self.error("Cannot make node mapping if no slot mapping is given")
+            return False
+
         va = self.va
         vb = self.vb
         Lb = self.Lb
@@ -292,18 +243,10 @@ class Versions:
         Eosb = Eb.oslots.s
         otypesa = Fa.otype.s
 
-        edge = self.edge
-
-        if edge is None:
-            print("Cannot make node mapping if no slot mapping is given")
-            return False
-
-        caption(2, "Mapping {} nodes {} ==> {}".format(nodeType, va, vb))
+        self.caption(2, f"Mapping {nodeType} nodes {va} ==> {vb}")
 
         diag = {}
-        caption(
-            0, "Extending slot mapping {} ==> {} for {} nodes".format(va, vb, nodeType)
-        )
+        self.caption(0, f"Extending slot mapping {va} ==> {va} for {nodeType} nodes")
         for n in otypesa(nodeType):
             slots = Eosa(n)
             mappedSlots = set(
@@ -359,14 +302,14 @@ class Versions:
                             diag[n] = "e"
 
         self.diagnosis[nodeType] = diag
-        caption(0, "\tDone")
+        self.caption(0, "\tDone")
 
     def exploreNodeMapping(self, nodeType):
         va = self.va
         vb = self.vb
         diagnosis = self.diagnosis
 
-        caption(4, "Statistics for {} ==> {} ({})".format(va, vb, nodeType))
+        self.caption(4, "Statistics for {} ==> {} ({})".format(va, vb, nodeType))
 
         diag = diagnosis[nodeType]
         total = len(diag)
@@ -378,14 +321,16 @@ class Versions:
         for (n, dia) in diag.items():
             reasons[dia] += 1
 
-        caption(0, "\t{:<30} : {:6.2f}% {:>7}x".format("TOTAL", 100, total))
+        self.caption(-1, "\t{:<30} : {:6.2f}% {:>7}x".format("TOTAL", 100, total))
         for stat in STAT_LABELS:
             statLabel = STAT_LABELS[stat]
             amount = reasons[stat]
             if amount == 0:
                 continue
             perc = 100 * amount / total
-            caption(0, "\t{:<30} : {:6.2f}% {:>7}x".format(statLabel, perc, amount))
+            self.caption(
+                -1, "\t{:<30} : {:6.2f}% {:>7}x".format(statLabel, perc, amount)
+            )
 
     def getDiagnosis(self, node=None, label=None):
         """Show the diagnosis of a mapping.
@@ -463,21 +408,22 @@ class Versions:
         """
 
         for (acro, desc) in STAT_LABELS.items():
-            print(f"{acro} = {desc}")
+            self.info(f"{acro} = {desc}", tm=False)
 
     def omapName(self):
         va = self.va
         vb = self.vb
-        return f"omap#{va}-{vb}"
+        return f"omap@{va}-{vb}"
 
     def writeMap(self):
         TFb = self.TFb
         va = self.va
         vb = self.vb
         edge = self.edge
+        silent = self.silent
 
         fName = self.omapName()
-        caption(4, "Write edge as TF feature {}".format(fName))
+        self.caption(4, "Write edge as TF feature {}".format(fName))
 
         edgeFeatures = {fName: edge}
         metaData = {
@@ -494,6 +440,7 @@ class Versions:
             nodeFeatures={},
             edgeFeatures=edgeFeatures,
             metaData=metaData,
+            silent=silent,
         )
 
     def makeVersionMapping(self):
@@ -509,12 +456,35 @@ class Versions:
 
         self.writeMap()
 
-    def migrateFeatures(self, featureNames, location=None):
+    def migrateFeatures(self, featureNames, silent=None, location=None):
         """Migrate features from one version to another based on a node map.
 
         If you have a dataset with several features, and if there is a node map between
         the versions, you can migrate features from the older version to the newer.
 
+        The naive approach per feature is:
+
+        For each node in the old version that has a value for the feature,
+        map the node to the new version.
+        That could be several nodes.
+        Then give all those nodes the value found on the node in the old set.
+
+        The problem with that is this:
+
+        Suppose node `n` in the old version maps to nodes `p` and `q` in the
+        new version, but not with the same quality.
+        Suppose the value is `v`. Then the feature assignment will assign
+        `v` to nodes `p` and `q`.
+
+        But there could very wel be a later node `m` with value `w` in the old version
+        that also maps to `p`, and with a lower quality.
+        Then later the node `p` in the new version will be assigned the value `w`
+        because of this, and this is sub otpimal.
+
+        So we make sure that for each feature and each node in the new version
+        the value assigned to it is the value of the node in the old version that
+        maps with the highest quality to the new node.
+
         Parameters
         ----------
         featureNames: tuple
@@ -523,35 +493,100 @@ class Versions:
         location: string, optional `None`
             If absent, the migrated features will be saved in the newer dataset.
             Otherwise it is a path where the new features should be saved.
+        silent: string, optional None
+            See `tf.core.timestamp.Timestamp`
+            This will override the `silent` setting
+            that has been used when creating the `Versions` object.
         """
 
+        silent = self.silent if silent is None else silentConvert(silent)
+        omapName = self.omapName()
         TFa = self.TFa
         TFb = self.TFb
+        TFb.setSilent(silent)
+        TFb.warning("start migrating")
+        TFb.load(omapName, add=True, silent=silent)
         Fsa = self.Fsa
+        Esa = self.Esa
         Esb = self.Esb
+        va = self.va
         vb = self.vb
 
-        emap = Esb(self.omapName()).f
+        emap = Esb(omapName).f
 
         nodeFeatures = {}
         edgeFeatures = {}
         metaData = {}
 
+        def getBestMatches(n, dest):
+            result = []
+            mapped = emap(n)
+
+            if mapped:
+                perfect = [x for x in mapped if x[1] is None]
+                if perfect:
+                    return [perfect[0]]
+
+                nearPerfect = [x for x in mapped if x[1] == 0]
+                if nearPerfect:
+                    (m, q) = nearPerfect[0]
+                    if m not in dest or m in dest and dest[m][1] is not None:
+                        return [nearPerfect[0]]
+
+                for (m, q) in mapped:
+                    # these q cannot be None or 0
+                    if m in dest:
+                        (origVal, origQ) = dest[m]
+                        higherQuality = origQ is not None and q < origQ
+                        if origVal == val:
+                            if higherQuality:
+                                result.append((m, q))
+                        elif higherQuality:
+                            result.append((m, q))
+                    else:
+                        result.append((m, q))
+            return result
+
         for featureName in featureNames:
-            featureObj = Fsa(featureName)
+            isEdge = TFa.features[featureName].isEdge
+            TFb.info(f"Mapping {featureName} ({'edge' if isEdge else 'node'})")
+            featureObj = (Esa if isEdge else Fsa)(featureName)
             featureInfo = dict(featureObj.items())
             metaData[featureName] = featureObj.meta
+            metaData[featureName]["upgraded"] = f"‼️ from version {va} to {vb}"
 
-            isEdge = TFa.features[featureName].isEdge
             edgeValues = featureObj.doValues if isEdge else False
 
             dest = edgeFeatures if isEdge else nodeFeatures
             dest[featureName] = {}
             dest = dest[featureName]
 
+            # we will not only store the feature value in dest,
+            # but also the quality of the mapping that
+            # produced the value.
+            # We only override an existing value
+            # if the quality of the mapping is better.
+            # Moreover, if one mapping has quality 0,
+            # it means that the mapping is perfect regarding the material in both nodes
+            # but there are lesser mappings as well.
+            # In those cases we do not extend the value to those lesser mappings
+            # Later, we strip the qualities again.
+
             if isEdge:
                 if edgeValues:
                     for (n, ts) in featureInfo.items():
+                        matched = getBestMatches(n, dest)
+                        if matched:
+                            matchedTs = {}
+                            for (t, val) in ts.items():
+                                for (t, r) in getBestMatches(t, matchedTs):
+                                    matchedTs[t] = (val, r)
+                            for t in matchedTs:
+                                matchedTs[t] = matchedTs[t][0]
+                            for (m, q) in matched:
+                                dest[m] = (matchedTs, q)
+
+                        """
                         mapped = emap(n)
                         if mapped:
                             mappedts = {}
@@ -562,24 +597,38 @@ class Versions:
                                         mappedts[tEntry[0]] = val
                             for entry in mapped:
                                 dest[entry[0]] = mappedts
+                                """
                 else:
                     for (n, ts) in featureInfo.items():
+                        matched = getBestMatches(n, dest)
+                        if matched:
+                            matchedTs = {}
+                            for t in ts:
+                                for (t, r) in getBestMatches(t, matchedTs):
+                                    matchedTs[t] = (None, r)
+                            matchedTs = set(matchedTs)
+                            for (m, q) in matched:
+                                dest[m] = (matchedTs, q)
+
+                        """
                         mapped = emap(n)
                         if mapped:
                             mappedts = set()
                             for t in ts:
                                 tmapped = emap(t)
                                 if tmapped:
-                                    for tm in tmapped:
-                                        mappedts.add(tm)
-                            for m in mapped:
-                                dest[m] = mappedts
+                                    for tEntry in tmapped:
+                                        mappedts.add(tEntry[0])
+                            for entry in mapped:
+                                dest[entry[0]] = mappedts
+                                """
             else:
                 for (n, val) in featureInfo.items():
-                    mapped = emap(n)
-                    if mapped:
-                        for entry in mapped:
-                            dest[entry[0]] = val
+                    for (m, q) in getBestMatches(n, dest):
+                        dest[m] = (val, q)
+
+            for m in dest:
+                dest[m] = dest[m][0]
 
         TFb.save(
             nodeFeatures=nodeFeatures,
@@ -587,4 +636,71 @@ class Versions:
             metaData=metaData,
             location=location,
             module=vb,
+            silent=silent,
         )
+        TFb.warning("Done")
+
+    def caption(self, level, heading, good=None, newLine=True, continuation=False):
+        silent = self.silent
+        prefix = "" if good is None else "SUCCES " if good else "FAILURE "
+        reportHeading = "{}{}".format(prefix, heading)
+
+        emit = (
+            silent == VERBOSE
+            or silent == AUTO
+            and level in {-1, 2, 3, 4}
+            or silent == TERSE
+            and level in {2, 3}
+        )
+
+        if level in {-1, 0}:  # non-heading message
+            decoration = "" if continuation else "| "
+            formattedString = """{}{}""".format(decoration, reportHeading)
+        elif level == 1:  # pipeline level
+            formattedString = """
+##{}##
+# {} #
+# {} #
+# {} #
+##{}##
+    """.format(
+                "#" * 90,
+                " " * 90,
+                "{:<90}".format(reportHeading),
+                " " * 90,
+                "#" * 90,
+            )
+        elif level == 2:  # repo level
+            formattedString = """
+    **{}**
+    * {} *
+    * {} *
+    * {} *
+    **{}**
+    """.format(
+                "*" * 90,
+                " " * 90,
+                "{:<90}".format(reportHeading),
+                " " * 90,
+                "*" * 90,
+            )
+        elif level == 3:  # task level
+            formattedString = """
+    --{}--
+    - {} -
+    --{}--
+    """.format(
+                "-" * 90,
+                "{:<90}".format(reportHeading),
+                "-" * 90,
+            )
+        elif level == 4:  # caption within task execution
+            formattedString = """..{}..
+    . {} .
+    ..{}..""".format(
+                "." * 90,
+                "{:<90}".format(reportHeading),
+                "." * 90,
+            )
+        if emit:
+            self.info(formattedString, nl=newLine, tm=not continuation, force=True)
