@@ -267,7 +267,7 @@ def _validateFeature(
 
 def _validation(searchExe):
     levels = searchExe.api.C.levels.data
-    otypes = set(x[0] for x in levels)
+    otypes = {x[0] for x in levels}
     qnodes = searchExe.qnodes
     nodeLine = searchExe.nodeLine
     edgeMap = searchExe.edgeMap
@@ -327,7 +327,7 @@ def _validation(searchExe):
 
     # check the relational operator token in edges
     # and replace them by an index
-    # in the relations array of known relations
+    # in the relations list of known relations
     qedges = []
     edgesGood = True
 
