@@ -88,7 +88,7 @@ def _spread_1_first(searchExe):
 
     newNodes = startS1[0]
     newEdges = startS1[1]
-    doneEdges = set(e[0] for e in newEdges)
+    doneEdges = {e[0] for e in newEdges}
 
     # we add all edges that are not yet in our startS1.
     # we add them two-fold: also with converse,
@@ -619,7 +619,7 @@ def _stitchResults(searchExe):
     # But we do not have to pass on the stitch as an immutable data structure.
     # We can just keep it as one single mutable datastructure, provided we
     # do something between the two recursive calls above.
-    # Suppose stitch is an array, and in the outer build n elements are filled
+    # Suppose stitch is an list, and in the outer build n elements are filled
     # (the rest contains -1)
     #
     # Then we say
