@@ -18,7 +18,7 @@ see *Kernel API* below.
 You can run the TF kernel as follows:
 
 ```sh
-python3 -m tf.server.kernel ddd
+python -m tf.server.kernel ddd
 ```
 
 where `ddd` points to a corpus, see `tf.app.use`.
@@ -79,11 +79,10 @@ import sys
 import pickle
 from functools import reduce
 
-import rpyc
-from rpyc.utils.server import ThreadedServer
-
 from ..parameters import GH
+from ..capable import Capable
 from ..core.helpers import console
+from ..core.timestamp import AUTO
 from ..advanced.app import findApp
 from ..advanced.highlight import getPassageHighlights
 from ..advanced.search import runSearch, runSearchCondensed
@@ -93,6 +92,12 @@ from ..advanced.text import specialCharacters
 
 from .command import argKernel
 
+
+Cap = Capable("browser")
+rpyc = Cap.load("rpyc")
+ThreadedServer = Cap.loadFrom("rpyc", "ThreadedServer")
+
+
 TF_DONE = "TF setup done."
 TF_ERROR = "Could not set up TF"
 
@@ -101,9 +106,14 @@ TF_ERROR = "Could not set up TF"
 
 
 def makeTfKernel(app, appName, port):
+    if not Cap.can("browser"):
+        console(f"{TF_ERROR}")
+        return False
+
     if not app.api:
         console(f"{TF_ERROR}")
         return False
+
     TF = app.api.TF
     reset = TF.reset
     cache = TF.cache
@@ -466,15 +476,17 @@ def makeTfKernel(app, appName, port):
             total = 0
 
             results = ()
+            status = True
             messages = ("", "")
             if query:
-                (results, messages, features) = (
+                (results, status, messages, features) = (
                     runSearchCondensed(app, query, cache, condenseType)
                     if condensed and condenseType
                     else runSearch(app, query, cache)
                 )
 
-                if messages[0]:
+                status = status[0] and status[1]
+                if not status:
                     results = ()
                 total += len(results)
 
@@ -506,7 +518,7 @@ def makeTfKernel(app, appName, port):
                 getx=getx,
                 **options,
             )
-            return (table, " ".join(messages), featureStr, start, total)
+            return (table, status, " ".join(messages), featureStr, start, total)
 
         def exposed_csvs(self, query, tuples, sections, **options):
             """Gets query results etc. in plain csv format.
@@ -548,16 +560,20 @@ def makeTfKernel(app, appName, port):
             queryMessages = ("", "")
             features = ()
             if query:
-                (queryResults, queryMessages, features) = runSearch(app, query, cache)
-                (queryResultsC, queryMessagesC, featuresC) = (
+                (queryResults, queryStatus, queryMessages, features) = runSearch(
+                    app, query, cache
+                )
+                (queryResultsC, queryStatusC, queryMessagesC, featuresC) = (
                     runSearchCondensed(app, query, cache, condenseType)
-                    if not queryMessages[0] and condensed and condenseType
-                    else (None, ("", ""), None)
+                    if queryStatus[0] and queryStatus[1] and condensed and condenseType
+                    else (None, (False, False), ("", ""), None)
                 )
 
-                if queryMessages[0]:
+                queryStatus = queryStatus[0] and queryStatus[1]
+                queryStatusC = queryStatusC[0] and queryStatusC[1]
+                if not queryStatus:
                     queryResults = ()
-                if queryMessagesC[0]:
+                if not queryStatusC:
                     queryResultsC = ()
 
             csvs = (
@@ -583,6 +599,7 @@ def makeTfKernel(app, appName, port):
                 fmt=fmt,
             )
             return (
+                queryStatus,
                 " ".join(queryMessages[0]),
                 pickle.dumps(csvs),
                 pickle.dumps(tupleResultsX),
@@ -604,7 +621,10 @@ def makeTfKernel(app, appName, port):
 
 
 def makeTfConnection(lhost, port, timeout):
-    class TfConnection(object):
+    if not Cap.can("browser"):
+        return None
+
+    class TfConnection:
         def connect(self):
             try:
                 connection = rpyc.connect(
@@ -625,6 +645,11 @@ def makeTfConnection(lhost, port, timeout):
 def main(cargs=sys.argv):
     args = argKernel(cargs)
     if not args:
+        console(f"{TF_ERROR}")
+        return
+
+    if not Cap.can("browser"):
+        console(f"{TF_ERROR}")
         return
 
     (dataSource, portKernel) = args
@@ -653,6 +678,7 @@ def main(cargs=sys.argv):
         dataLoc,
         backend,
         True,
+        silent=AUTO,
         checkout=checkout,
         mod=moduleRefs,
         locations=locations,
@@ -661,6 +687,7 @@ def main(cargs=sys.argv):
         version=version,
     )
     if app is None:
+        console(f"{TF_ERROR}")
         return
 
     kernel = makeTfKernel(app, appName, portKernel)
