@@ -82,9 +82,7 @@ import os
 import sys
 import pickle
 
-from flask import Flask, send_file
-from werkzeug.serving import run_simple
-
+from ..capable import Capable
 from ..parameters import HOST
 from ..core.helpers import console, abspath
 from ..server.kernel import makeTfConnection
@@ -102,8 +100,12 @@ from .serve import (
 
 MY_DIR = os.path.dirname(abspath(__file__))
 
+Cap = Capable("browser")
+(Flask, send_file) = Cap.loadFrom("flask", "Flask", "send_file")
+run_simple = Cap.loadFrom("werkzeug.serving", "run_simple")
 
-class Web(object):
+
+class Web:
     def __init__(self, portKernel):
         TF = makeTfConnection(HOST, int(portKernel), TIMEOUT)
         kernelApi = TF.connect()
@@ -193,6 +195,9 @@ def main(cargs=sys.argv):
     if not args:
         return
 
+    if not Cap.can("browser"):
+        return
+
     (dataSource, portKernel, portWeb) = args
 
     try:
